- [Home](/)
- [Installation](installation.md)
- [Quick Start Guide](quick-start.md)
- [Architecture](architecture.md)
  - [Core Components](architecture.md#core-components)
  - [Data Flow](architecture.md#data-flow)
  - [Flow Configuration](architecture.md#flow-configuration)
- [Blocks](blocks.md)
  - [Available Blocks](blocks.md#available-blocks)
  - [LLM Blocks](blocks.md#llm-blocks)
  - [Utility Blocks](blocks.md#utility-blocks)
- [Prompts](prompts.md)
  - [Configuration](prompts.md#configuration)
  - [Templates](prompts.md#templates)
- [Examples](examples.md)
  - [Knowledge Tuning](examples.md#knowledge-tuning)
  - [Skills Tuning](examples.md#skills-tuning)
- [Web Interface](web-interface.md)
- [Development](development.md)
  - [Contributing](development.md#contributing)
  - [Testing](development.md#testing)
  - [Commands](development.md#commands)
- [Changelog](changelog.md)